@@ -34,4 +34,21 @@ describe('SdcUserNavBtn', () => {
         expect($div.length).toBeGreaterThan(0);
     });
 
+});
+
+describe('User', () => {
+    let controller;
+
+    beforeEach(async () => {
+        // Create new controller instance based on the standard process.
+        controller = await test_utils.get_controller('user',
+                                                  {},
+                                                  '<div><h1>Controller Loaded</h1></div>');
+    });
+
+    test('Load Content', async () => {
+        const $div = $('body').find('user');
+        expect($div.length).toBeGreaterThan(0);
+    });
+
 });
\ No newline at end of file
